declare enum ActionTypes {
    PREV = "PREV",
    NEXT = "NEXT",
    SPECIFIC = "SPECIFIC",
    DONE = "DONE"
}
declare type PrevAction = {
    type: ActionTypes.PREV;
    payload: {
        length: number;
    };
};
declare type NextAction = {
    type: ActionTypes.NEXT;
    payload: {
        length: number;
    };
};
declare type DONEAction = {
    type: ActionTypes.DONE;
};
declare type SpecificAction = {
    type: ActionTypes.SPECIFIC;
    payload: {
        desired: number;
    };
};
declare type Action = PrevAction | NextAction | SpecificAction | DONEAction;
declare type State = {
    desired: number;
    active: number;
    transitionEnabled: boolean;
};
declare const loopReducer: (state: State, action: Action) => {
    desired: number;
    transitionEnabled: boolean;
    active: number;
} | undefined;
declare const carouselReducer: (state: State, action: Action) => {
    active: number;
    desired: number;
    transitionEnabled: boolean;
};
interface CarouselProps {
    loop: boolean;
    length: number;
    displayCount: number;
}
declare const useCarousel: ({ loop, length, displayCount }: CarouselProps) => {
    activeIndex: number;
    getCarouselProps: () => {
        style: {
            transition?: string;
            transform: string;
            left: string;
        };
        onTransitionEnd: () => void;
    };
    getPrevBtnProps: () => {
        onClick: () => void;
        prev: boolean;
        disabled: boolean;
    };
    getNextBtnProps: () => {
        onClick: () => void;
        next: boolean;
        disabled: boolean;
    };
    getSpecificBtnProps: ({ index }: {
        index: number;
    }) => {
        active: boolean;
        onClick: () => void;
    };
};
export { useCarousel, loopReducer, carouselReducer };
//# sourceMappingURL=hooks.d.ts.map